@@ -9,8 +9,13 @@
 # include "messages.h"
 # include "crypto.h"
 # include "alt_arc4random.h"
+# include "utils.h"
 
-# ifdef WITH_DMALLOC
+#ifdef HAVE_LIBSODIUM
+# include <sodium.h>
+#endif
+
+#ifdef WITH_DMALLOC
 #  include <dmalloc.h>
 # endif
 
@@ -323,8 +328,8 @@ void pw_mysql_check(AuthResult * const result,
     char *escaped_peer_ip = NULL;
     char *escaped_decimal_ip = NULL;
     int committed = 1;
-    int crypto_crypt = 0, crypto_mysql = 0, crypto_md5 = 0, crypto_sha1 = 0,
-        crypto_plain = 0;
+    int crypto_scrypt = 0, crypto_crypt = 0, crypto_mysql = 0, crypto_md5 = 0,
+        crypto_sha1 = 0, crypto_plain = 0;
     unsigned long decimal_ip_num = 0UL;
     char decimal_ip[42];
     char hbuf[NI_MAXHOST];
@@ -415,10 +420,13 @@ void pw_mysql_check(AuthResult * const result,
     }
     result->auth_ok--;                  /* -1 */
     if (strcasecmp(crypto, PASSWD_SQL_ANY) == 0) {
+        crypto_scrypt++;
         crypto_crypt++;
         crypto_mysql++;
         crypto_md5++;
         crypto_sha1++;
+    } else if (strcasecmp(crypto, PASSWD_SQL_SCRYPT) == 0) {
+        crypto_scrypt++;
     } else if (strcasecmp(crypto, PASSWD_SQL_CRYPT) == 0) {
         crypto_crypt++;
     } else if (strcasecmp(crypto, PASSWD_SQL_MYSQL) == 0) {
@@ -430,11 +438,19 @@ void pw_mysql_check(AuthResult * const result,
     } else {                           /* default to plaintext */
         crypto_plain++;
     }
+#ifdef HAVE_LIBSODIUM
+    if (crypto_scrypt != 0) {
+        if (crypto_pwhash_scryptsalsa208sha256_str_verify
+            (spwd, password, strlen(password)) == 0) {
+            goto auth_ok;
+        }
+    }
+#endif
     if (crypto_crypt != 0) {
         const char *crypted;
 
         if ((crypted = (const char *) crypt(password, spwd)) != NULL &&
-            strcmp(crypted, spwd) == 0) {
+            pure_strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
     }
@@ -464,7 +480,7 @@ void pw_mysql_check(AuthResult * const result,
 #  endif
 # endif
 #endif
-        if (strcmp(scrambled_password, spwd) == 0) {
+        if (pure_strcmp(scrambled_password, spwd) == 0) {
             goto auth_ok;
         }
     }
@@ -472,7 +488,7 @@ void pw_mysql_check(AuthResult * const result,
         const char *crypted;
 
         if ((crypted = (const char *) crypto_hash_md5(password, 1)) != NULL &&
-            strcmp(crypted, spwd) == 0) {
+            pure_strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
     }
@@ -480,13 +496,13 @@ void pw_mysql_check(AuthResult * const result,
         const char *crypted;
 
         if ((crypted = (const char *) crypto_hash_sha1(password, 1)) != NULL &&
-            strcmp(crypted, spwd) == 0) {
+            pure_strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
     }
     if (crypto_plain != 0) {
         if (*password != 0 &&    /* refuse null cleartext passwords */
-            strcmp(password, spwd) == 0) {
+            pure_strcmp(password, spwd) == 0) {
             goto auth_ok;
         }
     }
